@@ -1,7 +1,7 @@
 from beneath import config
 from beneath.cli.utils import async_cmd
 from beneath.client import Client
-from beneath.connection import BeneathError
+from beneath.connection import AuthenticationError
 
 
 def add_subparser(root):
@@ -16,6 +16,6 @@ async def auth(args):
     await client.connection.ensure_connected()
     config.write_secret(args.secret)
     print("You have authenticated successfully!")
-  except BeneathError:
+  except AuthenticationError:
     config.write_secret("")
     print("Your attempt to authenticate failed. Are you using an API secret generated in the Beneath web app?")
